# relax
(will) Provide differentiable versions of common HEP operations and objectives.

Browse or contribute to the [List of Differentiable Operations](list_of_operations.md).

## Developing

Clone and cd into the repo, then in a python venv run
```
python -m pip install -e .
```
to install dependencies.

Be sure to read [`CONTRIBUTING.md`](https://github.com/gradhep/relax/blob/master/CONTRIBUTING.md) before making a PR!
